#!/usr/bin/env python
# -*- coding: utf-8 -*-
import string
import numpy as np
import matplotlib.pyplot as plt
from pylab import *
from mpl_toolkits.basemap import Basemap
from mpl_toolkits.basemap import shiftgrid, cm
from netCDF4 import Dataset
import ffgrid2




## ATTENTION: lecture des fichiers NETCDF AMSUA - definition des variables dans "read_netcdf_AMSUA_test.py" ##
## lon
## lat
## jrs_MONTH
## chan
len_month = np.array([31, 28, 31, 30, 31, 30, 31])
#########################
## moyennes mensuelles ##
#########################
monthly_emis_JAN = np.zeros([len(chan), len(lat), len(lon)], float)
monthly_emis_FEB = np.zeros([len(chan), len(lat), len(lon)], float)
monthly_emis_MAR = np.zeros([len(chan), len(lat), len(lon)], float)
monthly_emis_APR = np.zeros([len(chan), len(lat), len(lon)], float)
monthly_emis_MAY = np.zeros([len(chan), len(lat), len(lon)], float)
monthly_emis_JUN = np.zeros([len(chan), len(lat), len(lon)], float)
monthly_emis_JUL = np.zeros([len(chan), len(lat), len(lon)], float)
for ich in range (0, len(chan)):
    for ilon in range (0, len(lon)):
        for ilat in range (0, len(lat)):
            monthly_emis_JAN[ich, ilat, ilon] = mean(emis_JAN[ich, ilat, ilon, :][nonzero(isnan(emis_JAN[ich, ilat, ilon, :]) == False)])
            monthly_emis_FEB[ich, ilat, ilon] = mean(emis_FEB[ich, ilat, ilon, :][nonzero(isnan(emis_FEB[ich, ilat, ilon, :]) == False)])
            monthly_emis_MAR[ich, ilat, ilon] = mean(emis_MAR[ich, ilat, ilon, :][nonzero(isnan(emis_MAR[ich, ilat, ilon, :]) == False)])
            monthly_emis_APR[ich, ilat, ilon] = mean(emis_APR[ich, ilat, ilon, :][nonzero(isnan(emis_APR[ich, ilat, ilon, :]) == False)])
            monthly_emis_MAY[ich, ilat, ilon] = mean(emis_MAY[ich, ilat, ilon, :][nonzero(isnan(emis_MAY[ich, ilat, ilon, :]) == False)])
            monthly_emis_JUN[ich, ilat, ilon] = mean(emis_JUN[ich, ilat, ilon, :][nonzero(isnan(emis_JUN[ich, ilat, ilon, :]) == False)])
            monthly_emis_JUL[ich, ilat, ilon] = mean(emis_JUL[ich, ilat, ilon, :][nonzero(isnan(emis_JUL[ich, ilat, ilon, :]) == False)])

monthly_emis = [monthly_emis_JAN, monthly_emis_FEB, monthly_emis_MAR, monthly_emis_APR, monthly_emis_MAY, monthly_emis_JUN, monthly_emis_JUL]

##############################
## plot moyennes mensuelles ##
##############################
## evolution de l'emissivite moyenne mensuelle dans une tranche de latitude ##
plt.ion()
for ilat in range (2, 7):
    plt.figure()
    plt.plot(lon, monthly_emis_JAN[0, ilat, :], 'r--', label = 'JAN')
    plt.plot(lon, monthly_emis_FEB[0, ilat, :], 'g--', label = 'FEB')
    plt.plot(lon, monthly_emis_MAR[0, ilat, :], 'b--', label = 'MAR')
    plt.plot(lon, monthly_emis_APR[0, ilat, :], 'm', label = 'APR')
    plt.plot(lon, monthly_emis_MAY[0, ilat, :], 'y', label = 'MAY')
    plt.plot(lon, monthly_emis_JUN[0, ilat, :], 'k', label = 'JUN')
    plt.plot(lon, monthly_emis_JUL[0, ilat, :], 'c', label = 'JUL')
    plt.xticks(np.arange(-180, 200, 20), rotation = 45)
    legend(bbox_to_anchor = (0., 1.02, 1., 0.01), loc = 3, ncol = 7)
    plt.ylabel('emissivity')
    plt.xlabel('longitude')
    plt.title('latitude: ' + str(lat[ilat]) + ' - CH1 - AMSUA')
    grid(True)
    plt.savefig('/usr/home/lahlod/twice_d/figures_output_ANTARC/AMSUA/emis_lon_lat' + str(lat[ilat]) + '_plt_FEB-APR-JUL_ch1_AMSUA.png')


## evolution biais dans une tranche de latitude ##
plt.figure()
lat_color = np.array(['r', 'm', 'b', 'g', 'c'])
for ilat in range (2, 7):
    plt.plot(lon, (monthly_emis_JAN[0, ilat, :] / monthly_emis_JUL[0, ilat, :]), lat_color[ilat-2], label = str(lat[ilat]))

legend(bbox_to_anchor = (0., 1.04), loc = 3, ncol = 5)
plt.xticks(np.arange(-180, 200, 20), rotation = 45)
plt.ylabel('emissivity bias')
plt.xlabel('longitude')
grid(True)
plt.title('emiss(JAN)/emiss(JUL)')
plt.plot(lon, np.ones([len(lon)]), 'k--')


################
## emissivite ##
################
Njr = np.sum(len_month)
emis_glob = np.zeros([len(chan), len(lat), len(lon), Njr], float)
for ich in range (0, len(chan)):
    for ilon in range (0, len(lon)):
        for ilat in range (0, len(lat)):
            e1 = np.append(emis_JAN[ich, ilat, ilon, :], emis_FEB[ich, ilat, ilon, :])
            e2 = np.append(e1, emis_MAR[ich, ilat, ilon, :])
            e3 = np.append(e2, emis_APR[ich, ilat, ilon, :])
            e4 = np.append(e3, emis_MAY[ich, ilat, ilon, :])
            e5 = np.append(e4, emis_JUN[ich, ilat, ilon, :])
            e6 = np.append(e5, emis_JUL[ich, ilat, ilon, :])
            emis_glob[ich, ilat, ilon, :] = e6

y_time, x_space = np.meshgrid(arange(0, Njr, 1), lon)
for ilat in range (2, 7):
    plt.figure()
    plt.title('emissivity - AMSUA - latitude ' + str(lat[ilat]))
    for ich in range (0, len(chan)):
        plt.subplot(2, 1, ich+1)
        plt.pcolor(x_space, y_time, emis_glob[ich, ilat, :, :], cmap=cm.s3pcpn_l_r, vmin = 0.5, vmax = 0.95)
        plt.axis([-180., 180., 0, Njr])
        cb = plt.colorbar()
        cb.set_label('CH ' + str(chan[ich]) + 'GHz')
        plt.yticks(np.array([0, 31, 59, 90, 120, 151, 181]), np.array(['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL']))
        plt.xticks(np.arange(-180, 200, 20), rotation = 30)
        plt.grid(True)
        plt.savefig('/usr/home/lahlod/twice_d/figures_output_ANTARC/AMSUA/hov_emis_lat' + str(lat[ilat]) + '_ch1-ch15_AMSUA.png')



#########################
## anomalie emissivite ##
#########################
emis_anom_glob = np.zeros([len(chan), len(lat), len(lon), Njr], float)
for ich in range (0, len(chan)):
    for ilon in range (0, len(lon)):
        for ilat in range (0, len(lat)):
            for indjr in range (15, Njr - 15): # moyenne glissante centree
                emis_anom_glob[ich, ilat, ilon, indjr] = emis_glob[ich, ilat, ilon, indjr][nonzero(emis_glob[ich, ilat, ilon, indjr] != 0.)] - mean(emis_glob[ich, ilat, ilon, indjr - 15 : indjr + 15][nonzero(emis_glob[ich, ilat, ilon, indjr - 15 : indjr + 15] != 0.)])



###################################################################
## variation saisonnière emissivite en fonction de type de glace ##
###################################################################

#### definition des zones d etaude ####

# zone1 et 2 = lon ([30E - 70E] et [90E - 160E]) tranche de lat [70S]
lat1 = np.where(lat == -70.)[0][0]
lon1 = np.where(lon == 30.)[0][0]
lon2 = np.where(lon == 75.)[0][0]
lon3 = np.where(lon == 90.)[0][0]
lon4 = np.where(lon == 165.)[0][0]
# zone3 = lon ([100W - 80W] tranche de lat [80S]
lat2 = np.where(lat == -80.)[0][0]
lon5 = np.where(lon == -100.)[0][0]
lon6 = np.where(lon == -75.)[0][0]
# zone4 = lon ([20W - 20E] tranche de lat [75S]
lat3 = np.where(lat == -75.)[0][0]
lon7 = np.where(lon == -20.)[0][0]
lon8 = np.where(lon == 25.)[0][0]
# zone5 = lon ([90E - 160E] tranche de lat [80S]
lon3 = np.where(lon == 90.)[0][0]
lon4 = np.where(lon == 165.)[0][0]
# zone6 = lon ([180W - 160W] tranche de lat [75S]
lon9 = np.where(lon == -180.)[0][0]
lon10 = np.where(lon == -155.)[0][0]
# zone7 = lon ([180E - 160E] tranche de lat [80S]
lon11 = np.where(lon == 160.)[0][0]
lon12 = np.where(lon == 180.)[0][0]
# zone8 = lon ([180E - 160E] tranche de lat [75S]
lon11 = np.where(lon == 160.)[0][0]
lon12 = np.where(lon == 180.)[0][0]
# zone9 = lon ([40E - 90E] tranche de lat [80S]
lon13 = np.where(lon == 40.)[0][0]
lon14 = np.where(lon == 95.)[0][0]
# zone10 = lon ([120W - 140W] tranche de lat [80S]
lon15 = np.where(lon == -140.)[0][0]
lon16 = np.where(lon == -115.)[0][0]

#### emissivite ####

emis_glob_jr = np.zeros([len(chan), Njr], float)
for ich in range (0, len(chan)):
    for indjr in range (0, Njr):
        emis_glob_jr[ich, indjr] = mean(emis_glob[ich, lat2, lon3 : lon4, indjr])


plt.ion()
plt.figure()
color_chan = np.array(['b', 'r'])
for ich in range (0, len(chan)):
    plt.plot(emis_glob_jr[ich, :][nonzero(emis_glob_jr[ich, :] != 0.)], color_chan[ich], label = str(chan[ich]) + 'GHz')

legend(loc = 4)
plt.xlim(0, 212)
plt.xticks(np.array([0, 31, 59, 90, 120, 151, 181]), np.array(['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL']), rotation = 30)
plt.ylabel('emissivitty')
grid(True)
plt.title('Seasonal variation of emissivity - zone[120W-140W;80S] - AMSUA (nadir)')

#### anomalie d emissivite (sur une moyenne glissante) ####

emis_anom_glob_jr = np.zeros([len(chan), Njr], float)
for ich in range (0, len(chan)):
    for indjr in range (0, Njr):
        emis_anom_glob_jr[ich, indjr] = mean(emis_anom_glob[ich, lat3, lon11 : lon12, indjr][nonzero(isnan(emis_anom_glob[ich, lat3, lon11 : lon12, indjr]) == False)])


plt.ion()
plt.figure()
color_chan = np.array(['b', 'r'])
for ich in range (0, len(chan)):
    plt.plot(emis_anom_glob_jr[ich, :], color_chan[ich], label = str(chan[ich]) + 'GHz')

legend(loc = 4)
plt.xlim(0, 212)
plt.xticks(np.array([0, 31, 59, 90, 120, 151, 181]), np.array(['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL']), rotation = 30)
plt.ylabel('emissivity anomaly')
grid(True)
plt.title('Seasonal variation of emissivity anomaly - zone[30E-70E;70S] - AMSUA (nadir)')

#### gradient de frequence ####

monthly_emis = np.array([monthly_emis_JAN, monthly_emis_FEB, monthly_emis_MAR, monthly_emis_APR, monthly_emis_MAY, monthly_emis_JUN, monthly_emis_JUL])
monthly_emis_mo = np.zeros([len(month), len(chan)], float)
for imo in range (0, len(month)):
    for ich in range(0, len(chan)):
        monthly_emis_mo[imo, ich] = mean(monthly_emis[imo, ich, lat2, lon15 : lon16])


monthly_emis_diff = monthly_emis_mo[:, 0] / monthly_emis_mo[:, 1]


plt.ion()
plt.figure()
color_chan = np.array(['b', 'r'])
subplot(2,1,1)
for ich in range (0, len(chan)):
    plt.plot(monthly_emis_mo[:, ich], color_chan[ich], label = str(chan[ich]) + 'GHz')

plt.ylabel('emissivity')
legend(loc = 4)
grid(True)
plt.title('Seasonal emissivity bias - zone[140W-120W;80S] - AMSUA (nadir)')
plt.xticks(np.arange(0, 7, 1), np.array(['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL']), rotation = 30)
subplot(2,1,2)
plot(monthly_emis_diff, 'k', label = 'bias')
plot(np.ones([len(month)]), 'g--')
plt.ylabel('bias (CH1/CH15)')
plt.xticks(np.arange(0, 7, 1), np.array(['JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL']), rotation = 30)
grid(True)




###############################
## biais emissivite par mois ##
###############################
biais_month = np.zeros([len(month), len(lat), len(lon)], float)
for imo in range (0, len(month)):
    biais_month[imo, :, :] = monthly_emis[imo][0, :, :] - monthly_emis[imo][1, :, :]

for imo in range (0, len(month)):
    plt.figure()
    plt.title('AMSUA [CH1-CH2] - '+str(month[imo])+' - (lat -80)')
    vlines(lon, [0], biais_month[imo, 2, :])
    xlabel('longitude')
    ylabel('bias(emissivity)')
    xlim(-180, 180)
    xticks(np.arange(-180., 200., 20), rotation = 30)
    grid(True)
    plt.savefig('/usr/home/lahlod/twice_d/figures_output_ANTARC/AMSUA/vlines_bias_emis_ch1-ch15_lat-80_'+str(month[imo])+'_AMSUA.png')


#############################
## var emissivite par mois ##
#############################
var = np.zeros([len(lat), len(lon)], float)
for ilon in range (0, len(lon)):
    for ilat in range (0, len(lat)):
        var[ilat, ilon] = np.sum((biais_month[:, ilat, ilon] - mean(biais_month[:, ilat, ilon]))**2)

var = var/7
for ilat in range (2, 7):
    plt.figure()
    vlines(lon, [0], var[ilat, :])
    xlabel('longitude')
    ylabel('var(emiss_bias)')
    plt.title('AMSUA [CH1-CH2] - lat '+str(lat[ilat]) )
    xlim(-180, 180)
    xticks(np.arange(-180., 200., 20), rotation = 30)
    grid(True)
    plt.savefig('/usr/home/lahlod/twice_d/figures_output_ANTARC/AMSUA/vlines_var_bias-emis_ch1-ch15_lat-'+str(lat[ilat])+'_AMSUA.png')


















plt.figure()
plt.ion()
#vlines(biais_month[0, 2])
#plt.subplot(2, 1, 1)
m = Basemap(llcrnrlon=-180, urcrnrlon=180, llcrnrlat=-90, urcrnrlat=-30, projection='cyl', resolution='c', fix_aspect=True)
m.drawcoastlines(linewidth = 1)
m.drawparallels(np.arange(-90., -30., 20))
m.drawmeridians(np.arange(-180., 180., 20))
xii,yii = m(*np.meshgrid(lon, lat))
clevs = (arange(0., 0.05, 0.0001))
cs = m.contourf(xii, yii, var, clevs, cmap=cm.s3pcpn_l_r)
cbar = colorbar(cs)
cbar.set_label('CH1 - 23.8GHz')
plt.title('var(emis) JUL - AMSUA')
xticks(arange(-180, 200, 20), rotation = 45)
yticks(arange(-90, -10, 20))
plt.subplot(2, 1, 2)
m = Basemap(llcrnrlon=-180, urcrnrlon=180, llcrnrlat=-90, urcrnrlat=-30, projection='cyl', resolution='c', fix_aspect=True)
m.drawcoastlines(linewidth = 1)
m.drawparallels(np.arange(-90., -30., 20))
m.drawmeridians(np.arange(-180., 180., 20))
xii,yii = m(*np.meshgrid(lon, lat))
clevs = (arange(0., 0.0035, 0.00001))
cs = m.contourf(xii, yii, var_JUL[1, :, :], clevs, cmap=cm.s3pcpn_l_r)
cbar = colorbar(cs)
cbar.set_label('CH15 - 89GHz')
xticks(arange(-180, 200, 20), rotation = 45)
yticks(arange(-90, -10, 20))





